@@ -2,7 +2,7 @@
 /*
  *  tokenizer.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Thu 09 Oct 2008 06:44:00 JST
+ *  Last-modified: Wed 02 Sep 2009 02:02:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_TOKENIZER_H
@@ -38,7 +38,6 @@
 #include <string>
 #include <vector>
 #include "tokenizer_func.h"
-#include "lexical_cast.h"
 
 namespace clx {
 	/* --------------------------------------------------------------------- */
@@ -65,8 +64,8 @@ namespace clx {
 		explicit basic_tokenizer(functor f = functor()) :
 			v_(), f_(f) {}
 		
-		template <class InputIterator>
-		explicit basic_tokenizer(InputIterator first, InputIterator last, functor f = functor()) :
+		template <class InIter>
+		explicit basic_tokenizer(InIter first, InIter last, functor f = functor()) :
 			v_(), f_(f) { this->assign(first, last); }
 		
 		explicit basic_tokenizer(const string_type& s, functor f = functor()) :
@@ -83,22 +82,22 @@ namespace clx {
 			f_.reset();
 		}
 		
-		template <class InputIterator>
-		const container& assign(InputIterator first, InputIterator last) {
-			string_type token;
+		template <class InIter>
+		const container& assign(InIter first, InIter last) {
+			value_type token;
 			
 			this->reset();
 			while (f_(first, last, token)) {
-				v_.insert(v_.end(), lexical_cast<value_type>(token));
+				v_.insert(v_.end(), token);
 				if (first == last) break;
-				++first;
+				token = value_type();
 			}
 			return v_;
 		}
 		
 		const container& assign(const string_type& s) {
-			typename string_type::const_iterator pos = s.begin();
-			return this->assign(pos, s.end());
+			if (s.empty()) return v_;
+			return this->assign(s.begin(), s.end());
 		}
 		
 		const container& assign(const char_type* s) {
@@ -106,8 +105,8 @@ namespace clx {
 			return this->assign(tmp);
 		}
 		
-		template <class InputIterator>
-		const container& operator()(InputIterator first, InputIterator last) {
+		template <class InIter>
+		const container& operator()(InIter first, InIter last) {
 			return this->assign(first, last);
 		}
 		
