@@ -2,7 +2,7 @@
 /*
  *  tokenizer_func.h
  *
- *  Copyright (c) 2004 - 2008, clown. All rights reserved.
+ *  Copyright (c) 2004 - 2009, clown. All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 26 Aug 2008 01:38:00 JST
+ *  Last-modified: Wed 02 Sep 2009 02:02:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_TOKENIZER_FUNC_H
@@ -91,7 +91,10 @@ namespace clx {
 			
 			string_type tmp;
 			while (next != last) { // obtain the next token.
-				if (std::find(c_.begin(), c_.end(), *next) != c_.end()) break;
+				if (std::find(c_.begin(), c_.end(), *next) != c_.end()) {
+					++next;
+					break;
+				}
 				tmp += *next;
 				++next;
 			}
@@ -124,7 +127,7 @@ namespace clx {
 		typedef typename std::basic_string<CharT, Traits> string_type;
 		
 		// constructor and destructor
-		escape_separator() : c_(1, LITERAL(',')), quote_(1, LITERAL('\\')), esc_(1, LITERAL('\"')), emtok_(false) {}
+		escape_separator() : c_(1, LITERAL(',')), quote_(1, LITERAL('\"')), esc_(1, LITERAL('\\')), emtok_(false) {}
 		
 		explicit escape_separator(char_type c, char_type q, char_type e, bool x = false) :
 			c_(1, c), quote_(1, q), esc_(1, e), emtok_(x) {}
@@ -158,9 +161,13 @@ namespace clx {
 			string_type tmp;
 			while (next != last) { // obtain the next token.
 				if (std::find(quote_.begin(), quote_.end(), *next) != quote_.end()) inq = !inq;
-				else if (!inq && std::find(c_.begin(), c_.end(), *next) != c_.end()) break;
+				else if (!inq && std::find(c_.begin(), c_.end(), *next) != c_.end()) {
+					++next;
+					break;
+				}
 				else {
 					if (std::find(esc_.begin(), esc_.end(), *next) != esc_.end()) ++next;
+					if (next == last) return false;
 					tmp += *next;
 				}
 				++next;
@@ -249,7 +256,6 @@ namespace clx {
 		
 	private:
 		char_type rep; // '%'
-		char_type eos; // '\0'
 		char_type ws;  // ' '
 		
 		string_type fmt_;
@@ -259,7 +265,6 @@ namespace clx {
 		
 		void init() {
 			rep = LITERAL('%');
-			eos = LITERAL('\0');
 			ws  = LITERAL(' ');
 		}
 		
@@ -288,9 +293,15 @@ namespace clx {
 			const string_type& normal, const string_type& flag) {
 			int n = -1;
 			if (!flag.empty() && isdigit(flag.at(0))) n = lexical_cast<int>(flag);
+			if (skipws_) {
+				while (next != last && *next == ' ') ++next;
+			}
+			
 			string_type dest;
 			while (next != last && n != 0) {
+				InIter prev = next;
 				if (this->compare(next, last, normal)) break;
+				next = prev;
 				dest += *next;
 				++next;
 				--n;
@@ -339,9 +350,9 @@ namespace clx {
 				if (skipws_ && *next == ws && *spos != ws) ++next;
 				else if (*next != *spos) return false;
 				else {
+					++next;
 					++spos;
 					if (spos == s.end()) break;
-					++next;
 				}
 			}
 			
